@@ -48,13 +48,6 @@ class Table(object):
                 {'name': 'cmenergies', 'values': []},
             ],
             'data_file': data_file or 'data%s.yaml' % index,
-            # it seems it's required
-            # TODO - is it really required? should sensible defaults be provided?
-            'data_license': {
-                'name': None,
-                'url': None,
-                'description': None # (optional)
-            },
             'additional_resources': [
                 # Below in the comments are listed allowed keys / values for additional_resources
                 #
@@ -148,7 +141,7 @@ class ParsedData(object):
 
     def get_table(self, **kwargs):
         assert len(kwargs) == 1
-        key, search_val = kwargs.items()[0]
+        key, search_val = list(kwargs.items())[0]
         assert key in ('id', 'name', 'file')
 
         if key == 'id':
@@ -165,9 +158,7 @@ class ParsedData(object):
             raise IndexError("No table with name = %s" % search_val)
 
 
-class Parser(GetConcreteSubclassMixin, OptionInitMixin):
-    __metaclass__  = abc.ABCMeta
-
+class Parser(GetConcreteSubclassMixin, OptionInitMixin, metaclass=abc.ABCMeta):
     def __init__(self, *args, **kwargs):
         OptionInitMixin.__init__(self, options=kwargs)
 
